@@ -1,10 +1,28 @@
-import pymssql
-from utils import mssql_exec
+from .utils import mssql_exec, mssql_get_list, mssql_get_one
 
 mssql = dict
 
 
-def grupo_insert(
+def get_list(db_config: mssql):
+    qry_grupos_planejamento = """
+        SELECT CodigoGrupoPlanejamento, Comprador, NomeLinha, NomeGrupo, Ativo, VendaQt_12M, VendaPV_12M, NomeChave
+        FROM Compras.VwGrupoPlanejamento
+        ORDER BY 2,3,4
+        """
+    return mssql_get_list(db_config, qry_grupos_planejamento)
+
+
+def get_one(db_config: mssql, codigo: int):
+    qry = """
+        SELECT CodigoGrupoPlanejamento, Comprador, NomeLinha, NomeGrupo, Ativo, Detalhes
+        FROM Compras.GrupoPlanejamento
+        WHERE CodigoGrupoPlanejamento = %d
+        """
+    params = (codigo,)
+    return mssql_get_one(db_config, qry, params)
+
+
+def create(
     db_config: mssql,
     comprador: str,
     nome_linha: str,
@@ -20,7 +38,7 @@ def grupo_insert(
     return mssql_exec(db_config, qry_insert, params)
 
 
-def grupo_update(
+def update(
     db_config: mssql,
     codigo: int,
     comprador: str,
@@ -43,7 +61,7 @@ def grupo_update(
     return mssql_exec(db_config, qry_update, params)
 
 
-def grupo_delete(db_config: mssql, codigo: int):
+def delete(db_config: mssql, codigo: int):
     qry_delete = """
       DELETE FROM Compras.GrupoPlanejamento WHERE CodigoGrupoPlanejamento = %d
     """
